"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.TokenClient = void 0;
class TokenClient {
    constructor(aptosClient) {
        this.aptosClient = aptosClient;
    }
    submitTransactionHelper(account, payload) {
        return __awaiter(this, void 0, void 0, function* () {
            const txnRequest = yield this.aptosClient.generateTransaction(account.address(), payload, {
                max_gas_amount: "4000",
            });
            const signedTxn = yield this.aptosClient.signTransaction(account, txnRequest);
            const res = yield this.aptosClient.submitTransaction(account, signedTxn);
            yield this.aptosClient.waitForTransaction(res.hash);
            return Promise.resolve(res.hash);
        });
    }
    // Creates a new collection within the specified account
    createCollection(account, description, name, uri) {
        return __awaiter(this, void 0, void 0, function* () {
            const payload = {
                type: "script_function_payload",
                function: "0x1::Token::create_unlimited_collection_script",
                type_arguments: [],
                arguments: [
                    Buffer.from(description).toString("hex"),
                    Buffer.from(name).toString("hex"),
                    Buffer.from(uri).toString("hex"),
                ],
            };
            const transactionHash = yield this.submitTransactionHelper(account, payload);
            return transactionHash;
        });
    }
    // Creates a new token within the specified account
    createToken(account, collectionName, description, name, supply, uri) {
        return __awaiter(this, void 0, void 0, function* () {
            const payload = {
                type: "script_function_payload",
                function: "0x1::Token::create_token_script",
                type_arguments: [],
                arguments: [
                    Buffer.from(collectionName).toString("hex"),
                    Buffer.from(description).toString("hex"),
                    Buffer.from(name).toString("hex"),
                    supply.toString(),
                    Buffer.from(uri).toString("hex"),
                ],
            };
            const transactionHash = yield this.submitTransactionHelper(account, payload);
            return transactionHash;
        });
    }
    // Offer token to another account
    offerToken(account, receiver, creator, tokenCreationNum, amount) {
        return __awaiter(this, void 0, void 0, function* () {
            const payload = {
                type: "script_function_payload",
                function: "0x1::TokenTransfers::offer_script",
                type_arguments: [],
                arguments: [receiver, creator, tokenCreationNum.toString(), amount.toString()],
            };
            const transactionHash = yield this.submitTransactionHelper(account, payload);
            return transactionHash;
        });
    }
    // Claim token
    claimToken(account, sender, creator, tokenCreationNum) {
        return __awaiter(this, void 0, void 0, function* () {
            const payload = {
                type: "script_function_payload",
                function: "0x1::TokenTransfers::claim_script",
                type_arguments: [],
                arguments: [sender, creator, tokenCreationNum.toString()],
            };
            const transactionHash = yield this.submitTransactionHelper(account, payload);
            return transactionHash;
        });
    }
    // Cancel token
    cancelTokenOffer(account, receiver, creator, tokenCreationNum) {
        return __awaiter(this, void 0, void 0, function* () {
            const payload = {
                type: "script_function_payload",
                function: "0x1::TokenTransfers::cancel_offer_script",
                type_arguments: [],
                arguments: [receiver, creator, tokenCreationNum.toString()],
            };
            const transactionHash = yield this.submitTransactionHelper(account, payload);
            return transactionHash;
        });
    }
    // Retrieve the token's creation_num, which is useful for non-creator operations
    getTokenId(creator, collectionName, tokenName) {
        return __awaiter(this, void 0, void 0, function* () {
            const resources = yield this.aptosClient.getAccountResources(creator);
            let collections = [];
            let tokens = [];
            const accountResource = resources.find((r) => r.type === "0x1::Token::Collections");
            collections = accountResource.data.collections.data;
            for (let index = 0; index < collections.length; index += 1) {
                if (collections[index].key === collectionName) {
                    tokens = collections[index].value.tokens.data;
                    break;
                }
            }
            for (let index = 0; index < tokens.length; index += 1) {
                if (tokens[index].key === tokenName) {
                    return parseInt(tokens[index].value.id.creation_num, 10);
                }
            }
            return null;
        });
    }
}
exports.TokenClient = TokenClient;
//# sourceMappingURL=token_client.js.map